@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 1998-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -83,11 +83,17 @@ INSTALLED_APPS = (
     # 'allauth.socialaccount.providers.facebook',
     'allauth.socialaccount.providers.twitter',
     'allauth.socialaccount.providers.stackexchange',
+
+    # Dev only dependencies. Do not include in any production site.
+    'debug_toolbar',
+    'requests_panel',
 )
 
 
 MIDDLEWARE = [
     'django.contrib.sessions.middleware.SessionMiddleware',
+    # NOTE: Do not include DebugToolbarMiddleware in any production site.
+    'debug_toolbar.middleware.DebugToolbarMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.middleware.locale.LocaleMiddleware',
@@ -140,6 +146,10 @@ DATABASES = {
     }
 }
 
+# Maintain type of autogenerated keys going forward
+# https://docs.djangoproject.com/en/3.2/releases/3.2/#customizing-type-of-auto-created-primary-keys
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
+
 # Password validation
 # https://docs.djangoproject.com/en/1.9/ref/settings/#auth-password-validators
 
@@ -290,10 +300,38 @@ LOGGING = {
 
 POSTORIUS_TEMPLATE_BASE_URL = "http://localhost:8000"
 
+#: Debug the API calls made by Postorius.
+POSTORIUS_API_DEBUG = False
 
-if DEBUG:
+if DEBUG and POSTORIUS_API_DEBUG:
     MIDDLEWARE.append('postorius.middleware.APICountingMiddleware')
 
+
+# Needed for django debug toolbar to show up.
+INTERNAL_IPS = ('127.0.0.1',)
+
+# List of panels that show up for django-debug-toolbar. They are
+# very useful for debugging and are ONLY REQUIRED FOR TESTING.
+DEBUG_TOOLBAR_PANELS = [
+    'requests_panel.panel.RequestsDebugPanel',
+    'debug_toolbar.panels.sql.SQLPanel',
+    'debug_toolbar.panels.templates.TemplatesPanel',
+
+    'debug_toolbar.panels.history.HistoryPanel',
+    'debug_toolbar.panels.versions.VersionsPanel',
+    'debug_toolbar.panels.timer.TimerPanel',
+    'debug_toolbar.panels.settings.SettingsPanel',
+    'debug_toolbar.panels.headers.HeadersPanel',
+    'debug_toolbar.panels.request.RequestPanel',
+    'debug_toolbar.panels.staticfiles.StaticFilesPanel',
+    'debug_toolbar.panels.cache.CachePanel',
+    'debug_toolbar.panels.signals.SignalsPanel',
+    'debug_toolbar.panels.logging.LoggingPanel',
+    'debug_toolbar.panels.redirects.RedirectsPanel',
+    'debug_toolbar.panels.profiling.ProfilingPanel',
+
+]
+
 try:
     from settings_local import *
 except ImportError:
