@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 1998-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -20,8 +20,9 @@
 Django test settings for postorius project.
 """
 
-from settings import *
+from .settings import *
 
+ROOT_URLCONF = 'example_project.urls'
 
 TESTING = True
 
