@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 1998-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -18,12 +18,16 @@
 
 
 from django import template
-
-from postorius.auth.utils import user_is_in_list_roster
-from postorius.models import List
+from django.utils.translation import gettext_lazy as _
 
 from mailmanclient import MailingList
 
+from postorius.auth.utils import user_is_in_list_roster
+from postorius.forms.fields import DELIVERY_MODE_CHOICES
+from postorius.forms.list_forms import ACTION_CHOICES
+from postorius.models import List
+
+
 register = template.Library()
 
 __all__ = [
@@ -49,7 +53,7 @@ def user_is_list_owner(user, mlist):
     Given a User object and a MailingList object/identifier, returns True if
     the user is an owner of the given MailingList False otherwise.
     """
-    return user_is_in_list_roster(user, get_list(mlist), 'owners')
+    return user_is_in_list_roster(user, get_list(mlist), 'owner')
 
 
 @register.simple_tag
@@ -58,4 +62,23 @@ def user_is_list_moderator(user, mlist):
     Given a User object and a MailingList object/identifier, return True if
     the user is one of the list moderators, False otherwise.
     """
-    return user_is_in_list_roster(user, get_list(mlist), 'moderators')
+    return user_is_in_list_roster(user, get_list(mlist), 'moderator')
+
+
+@register.filter
+def owner_repr(owner):
+    name = owner.display_name or ''
+    address = owner.addresses[0].original_email
+    return '{} {}'.format(name, address)
+
+
+@register.filter
+def delivery_mode(value):
+    """Convert the delivery_mode value into translated value."""
+    return dict(DELIVERY_MODE_CHOICES).get(value, _("None"))
+
+
+@register.filter
+def moderation_action(value):
+    """Convert the moderation_action value into translated text."""
+    return dict(ACTION_CHOICES).get(value, _("None"))
