@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -223,6 +223,32 @@ class ListMembersTest(ViewTestCase):
         self.assertContains(response, member_2.email)
         self.assertContains(response, '<small>(2)</small>')
 
+    def test_show_members_details(self):
+        """Test that Members's delivery related settings/preferences."""
+        self.client.login(username='testsu', password='testpass')
+        member_1 = self.foo_list.subscribe(
+            'member-1@example.com', pre_verified=True, pre_confirmed=True,
+            pre_approved=True)
+        member_1.delivery_mode = 'plaintext_digests'
+        member_1.moderation_action = 'hold'
+        member_1.save()
+        member_2 = self.foo_list.subscribe(
+            'member-2@example.com', pre_verified=True, pre_confirmed=True,
+            pre_approved=True)
+        member_2.delivery_mode = 'summary_digests'
+        member_2.moderation_action = 'defer'
+        member_2.save()
+        response = self.client.get(reverse(
+            'list_members', args=['foo.example.com', 'member']))
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(len(response.context['members']), 2)
+        for each in (
+                # Delivery mode settings.
+                'Plain Text Digests', 'Summary Digests',
+                # Moderatation action settings.
+                'Hold for moderation', 'Default processing'):
+            self.assertContains(response, each)
+
     def test_search_members_1(self):
         self.client.login(username='testsu', password='testpass')
         member_1 = self.foo_list.subscribe(
@@ -365,3 +391,38 @@ class ListNonMembersTest(ViewTestCase):
         nonmember_emails = [nm.email for nm in self.foo_list.nonmembers]
         self.assertEqual(len(nonmember_emails), 2)
         self.assertFalse('nonmember-1@example.com' in nonmember_emails)
+
+
+class TestMassRemoval(ViewTestCase):
+
+    def setUp(self):
+        super().setUp()
+        self.domain = self.mm_client.create_domain('example.com')
+        self.foo_list = self.domain.create_list('foo')
+        self.superuser = User.objects.create_superuser(
+            'testsu', 'su@example.com', 'testpass')
+        EmailAddress.objects.create(
+            user=self.superuser, email=self.superuser.email, verified=True)
+        self.client.login(username='testsu', password='testpass')
+
+    def tearDown(self):
+        self.foo_list.delete()
+        self.superuser.delete()
+        self.domain.delete()
+
+    def test_mass_removal(self):
+        member_list = []
+        for count in range(100):
+            member = f'member-{count}@example.com'
+            member_list.append(member)
+            self.foo_list.subscribe(
+                member, pre_verified=True, pre_confirmed=True,
+                pre_approved=True)
+        # Also, add an invalid address.
+        member_list.append('member@member@example.com')
+        self.assertEqual(len(self.foo_list.members), 100)
+        response = self.client.post(
+            reverse('mass_removal', args=('foo.example.com', )),
+            data=dict(emails='\n'.join(member_list)))
+        self.assertEqual(response.status_code, 302)
+        self.assertEqual(len(self.foo_list.members), 0)
