@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2016-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -226,6 +226,12 @@ class ListSettingsTest(ViewTestCase):
         self.assertContains(response, '<div class="paginator">')
 
     def test_handle_subscription_request(self):
+        self._test_handle_subscription('accept')
+
+    def test_handle_subscription_request_with_reason(self):
+        self._test_handle_subscription('reject', 'Private list')
+
+    def _test_handle_subscription(self, action, reason=None):
         self.client.login(username='testowner', password='testpass')
         self.foo_list.settings['subscription_policy'] = 'moderate'
         self.foo_list.settings.save()
@@ -234,14 +240,70 @@ class ListSettingsTest(ViewTestCase):
         self.assertEqual(len(self.foo_list.requests), 1)
         token = self.foo_list.requests[0]['token']
         url = reverse('handle_subscription_request',
-                      args=('foo.example.com', token, 'accept'))
-        response = self.client.get(url)
+                      args=('foo.example.com', token))
+        data = {action: True}
+        if reason:
+            data['reason'] = reason
+        response = self.client.post(url, data=data)
         # On success, user is redirected to list_subscription_requests page.
         self.assertTrue(response.status_code, 302)
-        self.assertTrue(response.url,
-                        '/postorius/lists/foo.example.com/subscription_requests')  # noqa
+        self.assertTrue(
+            response.url,
+            '/postorius/lists/foo.example.com/subscription_requests')
         self.assertEqual(len(self.foo_list.requests), 0)
 
+    def test_list_unsubscription_requests(self):
+        self.client.login(username='testowner', password='testpass')
+        url = reverse('list_unsubscription_requests',
+                      args=('foo.example.com',))
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+        self.foo_list.subscribe(
+            'someone@example.com', pre_verified=True, pre_confirmed=True,
+            pre_approved=True)
+        # Since there are no pending usubscription requests, this page should
+        # be empty.
+        self.assertContains(response, '<small>(0)</small>')
+        self.assertTrue(
+            b'There are currently no subscription requests for this list.'
+            in response.content)
+        self.assertNotContains(response, '<div class="paginator">')
+        # We set subscription policy to 'confirm', which should wait for the
+        # user approval.
+        self.foo_list.settings['unsubscription_policy'] = 'moderate'
+        self.foo_list.settings.save()
+        self.foo_list.unsubscribe('someone@example.com', pre_approved=False)
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+        # Check that the request is shown in pending subscription requests.
+        self.assertTrue('someone@example.com' in str(response.content))
+        self.assertContains(response, '<small>(1)</small>')
+        # Verify that the list is paginated
+        self.assertContains(response, '<div class="paginator">')
+
+    def test_handle_unsubscription_requests(self):
+        self.client.login(username='testowner', password='testpass')
+        self.foo_list.settings['unsubscription_policy'] = 'moderate'
+        self.foo_list.settings.save()
+        self.foo_list.subscribe(
+            'test@example.com', pre_verified=True, pre_approved=True,
+            pre_confirmed=True)
+        self.assertEqual(len(self.foo_list.members), 1)
+        self.foo_list.unsubscribe('test@example.com', pre_approved=False)
+        # There should be one pending unsubscription request.
+        self.assertEqual(len(self.foo_list.unsubscription_requests), 1)
+        token = self.foo_list.unsubscription_requests[0]['token']
+        url = reverse('handle_subscription_request',
+                      args=('foo.example.com', token))
+        response = self.client.post(url, data={'accept': True})
+        # On success, user is redirected to list_subscription_requests page.
+        self.assertTrue(response.status_code, 302)
+        self.assertTrue(
+            response.url,
+            '/postorius/lists/foo.example.com/subscription_requests')
+        self.assertEqual(len(self.foo_list.requests), 0)
+        self.assertEqual(len(self.foo_list.members), 0)
+
     def test_remove_all_subscribers(self):
         self.client.login(username='testowner', password='testpass')
         # Let's add 10 subscribers to the list.
@@ -317,6 +379,9 @@ class ListSettingsTest(ViewTestCase):
         response = self.client.post(url, updated_values)
 
         self.assertEqual(response.status_code, 200)
+        self.assertIn(
+            b'The address john3@example.com has been subscribed to'
+            b' foo@example.com.\n', response.content)
         self.assertEqual(len(mlist.members), 1)
 
         # Now, let's see if we can moderate.
@@ -333,8 +398,11 @@ class ListSettingsTest(ViewTestCase):
         self.assertEqual(len(mlist.members), 1)
         response = self.client.post(url, updated_values)
         self.assertEqual(response.status_code, 200)
+        self.assertIn(
+            b'The address john@example.com has been subscribed to'
+            b' foo@example.com.\n', response.content)
         self.assertEqual(len(mlist.members), 2)
-        # With pre_confirmed = False, there should be a pending subscription
+        # With pre_approved = False, there should be a pending subscription
         # event.
         updated_values = {
             'emails': 'john2@example.com',
@@ -343,6 +411,11 @@ class ListSettingsTest(ViewTestCase):
         }
         response = self.client.post(url, updated_values)
         self.assertEqual(response.status_code, 200)
+        self.assertIn(
+            b'The address john2@example.com has been subscribed to'
+            b' foo@example.com. Subscription may be pending address'
+            b' verification, confirmation or approval as appropriate.\n',
+            response.content)
         # Now, there should be a pending request to confirm.
         self.assertEqual(len(mlist.members), 2)
         self.assertEqual(len(mlist.requests), 1)
@@ -360,6 +433,11 @@ class ListSettingsTest(ViewTestCase):
 
         response = self.client.post(url, updated_values)
         self.assertEqual(response.status_code, 200)
+        self.assertIn(
+            b'The address john4@example.com has been subscribed to'
+            b' foo@example.com. Subscription may be pending address'
+            b' verification, confirmation or approval as appropriate.\n',
+            response.content)
         self.assertEqual(len(mlist.requests), 2)
         self.assertEqual(mlist.requests[1].get('token_owner'), 'subscriber')
 
@@ -371,6 +449,9 @@ class ListSettingsTest(ViewTestCase):
         }
         response = self.client.post(url, updated_values)
         self.assertEqual(response.status_code, 200)
+        self.assertIn(
+            b'The address john5@example.com has been invited to'
+            b' foo@example.com.\n', response.content)
         # And now there are 3 requests.
         self.assertEqual(len(mlist.requests), 3)
         self.assertEqual(mlist.requests[2].get('token_owner'), 'subscriber')
