@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2017-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2017-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -96,13 +96,35 @@ class TestListSubscribe(TestCase):
         self.assertEqual(form.errors['subscriber'][0],
                          'Please enter a valid email address.')
 
+    def test_list_subscribe_with_delivery_mode(self):
+        user_emails = ['aperson@example.com']
+        form = ListSubscribe(user_emails,
+                             '00000000000000000000000000000004',
+                             'aperson@example.com',
+                             {'subscriber': '00000000000000000000000000000004',
+                              'delivery_mode': 'plaintext_digests',
+                              'delivery_status': 'by_user'})
+        self.assertTrue(form.is_valid())
+
+    def test_list_subscribe_with_invalid_delivery_status(self):
+        user_emails = ['aperson@example.com']
+        form = ListSubscribe(user_emails,
+                             '00000000000000000000000000000004',
+                             'aperson@example.com',
+                             {'subscriber': '00000000000000000000000000000004',
+                              'delivery_mode': 'plaintext_digest',
+                              'delivery_status': 'by_bounces'})
+        self.assertFalse(form.is_valid())
+        self.assertTrue('delivery_status' in form.errors)
+
 
 class TestChangeSubscription(TestCase):
 
     def test_subscription_changes_only_to_user_addresses(self):
         user_emails = ['one@example.com', 'two@example.com']
         form = ChangeSubscriptionForm(user_emails, None, None,
-                                      {'subscriber': 'abcd@d.com'})
+                                      {'subscriber': 'abcd@d.com',
+                                       'member_id': '1235sdfsd314'})
         self.assertFalse(form.is_valid())
         self.assertTrue('subscriber' in form.errors.keys())
         self.assertEqual(form.errors['subscriber'][0],
@@ -112,12 +134,14 @@ class TestChangeSubscription(TestCase):
     def test_subscription_works(self):
         user_emails = ['one@example.com', 'two@example.com']
         form = ChangeSubscriptionForm(user_emails, None, None,
-                                      {'subscriber': 'two@example.com'})
+                                      {'subscriber': 'two@example.com',
+                                       'member_id': '1235sdfsd314'})
         self.assertTrue(form.is_valid())
 
     def test_subscription_form_labels(self):
         user_emails = ['one@example.com', 'two@example.com']
-        form = ChangeSubscriptionForm(user_emails, None, None, {})
+        form = ChangeSubscriptionForm(user_emails, None, None,
+                                      {'member_id': '1235sdfsd314'})
         self.assertTrue(form.is_valid())
         self.assertEqual(form.fields['subscriber'].label, 'Select Email')
 
@@ -125,15 +149,16 @@ class TestChangeSubscription(TestCase):
         form = ChangeSubscriptionForm(
             ['email@example.com', 'john@example.com', 'doe@example.com'],
             None, None,
-            {'subscriber': 'email@example.com'})
+            {'subscriber': 'email@example.com',
+             'member_id': '1235sdfsd314'})
         self.assertTrue(form.is_valid())
 
     def test_required_fields(self):
-        # There is no required fields, so empty form should be valid.
+        # There is only one required fields.
         form = ChangeSubscriptionForm(
             ['email@example.com', 'john@example.com', 'doe@example.com'],
             None, None,
-            {})
+            {'member_id': '1235sdfsd314'})
         self.assertTrue(form.is_valid())
 
     def test_change_subscription_with_user_uuid(self):
@@ -142,8 +167,8 @@ class TestChangeSubscription(TestCase):
             user_emails,
             '00000000000000000000000000000004',
             'aperson@example.com',
-            {'subscriber': '00000000000000000000000000000004'}
-        )
+            {'subscriber': '00000000000000000000000000000004',
+             'member_id': '1235sdfsd314'})
         self.assertEqual(form.is_valid(), True)
 
     def test_subscribe_with_invalid_uuid(self):
@@ -545,6 +570,26 @@ class TestArchiveSettingsForm(TestCase):
         self.assertEqual(form.initial['archivers'],
                          ['hyperkitty', 'pipermail'])
 
+    def test_optional_archive_rendering_field(self):
+        # Test that archive rendering mode is set only when Hyperkitty is
+        # installed.
+        formdata = dict(archive_policy='public',
+                        archivers=['pipermail'])
+        form = ArchiveSettingsForm(formdata, mlist=self.mlist,
+                                   initial={'archivers': None})
+        self.assertTrue(form.is_valid())
+        self.assertFalse('archive_rendering_mode' in form.fields)
+        # With Hyperkitty installed, the field should show up.
+        with unittest.mock.patch(
+                'postorius.forms.list_forms.apps.is_installed',
+                return_value=True):
+            formdata = dict(archive_policy='public',
+                            archivers=['pipermail'])
+            form = ArchiveSettingsForm(formdata, mlist=self.mlist,
+                                       initial={'archivers': None})
+            self.assertTrue(form.is_valid())
+            self.assertTrue('archive_rendering_mode' in form.fields)
+
 
 class TestMemberPolicyForm(TestCase):
 
